/**
  *  \file client/widgets/allylevelgrid.h
  *  \brief Alliance Level Grid
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_ALLYLEVELGRID_H
#define PCC_V2_CLIENT_WIDGETS_ALLYLEVELGRID_H

#include "ui/ui.h"

class GAlliances;

/** Alliance Level Grid.
    Displays a player's alliance relations to another player in a grid of checkboxes.
    The user's offers can be edited.

    The offering player (subject) is defined by the GAlliances object which contains one player's alliances.
    The offered player (object) is set using the setPlayer() method.
    setPosition() allows to place the cursor on a checkbox.

    User must arrange for WAllyLevelGrid::drawWidget() to be called if the GAlliances object changes. */
class WAllyLevelGrid : public UIWidget {
 public:
    WAllyLevelGrid(int id, GAlliances& editAllies);

    void getLayoutInfo(LayoutInfo&);
    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);
    void onStateChange(int state, bool enable);

    void setPlayer(int player);

    void setPosition(int newPos);
    void toggleCurrent();

 private:
    bool mouseDown;
    int player;
    int position;
    GAlliances& editAllies;
};

#endif
