/**
  *  \file game/planettransfer.cc
  *  \brief Planet Transfer
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/planettransfer.h"
#include "game/planet.h"
#include "game/error.h"
#include "util/nls.h"
#include "game/actions/preconditions.h"
#include "game/config.h"

GPlanetTransfer::GPlanetTransfer(GPlanet& planet)
    : planet(planet)
{
    setFlags(can_GetUnload | can_Sup2mc);
    planet.cargo_arbiter.incUseCount();
    mustBePlayed(planet);
}

GPlanetTransfer::~GPlanetTransfer()
{
    if (!isFinished()) {
        doCancel();
    }
    planet.cargo_arbiter.decUseCount();
}

int32_t
GPlanetTransfer::getCargoOnObject(GCargoType type)
{
    return planet.getCargo(type);
}

void
GPlanetTransfer::changeCargoOnObject(GCargoType type, int32_t amount)
{
    planet.changeCargoRaw(type, amount);
}

void
GPlanetTransfer::changeReservedCargo(GCargoType type, int32_t amount)
{
    planet.cargo_arbiter.changeReservedCargo(type, amount);
}

bool
GPlanetTransfer::canHaveCargo(GCargoType cargo_id)
{
    if (cargo_id == el_Fighters
        || (cargo_id >= el_Torps && cargo_id < el_Torps + NUM_TORPS))
    {
        if (!planet.hasBase())
            return false;
    }
    return true;
}

int32_t
GPlanetTransfer::getMaxCargo(GCargoType cargo_id)
{
    // FIXME: Host .31 torp safety
    /* the torp/ore limits are arbitrary, but should match Tim's TRN check. */
    if (cargo_id == el_Fighters)
        return config.MaximumFightersOnBase(planet.getOwner());
    else if (cargo_id >= el_Torps && cargo_id < el_Torps + NUM_TORPS)
        return 10000;
    else
        return 1000000000;
}

string_t
GPlanetTransfer::getName() const
{
    return planet.getName(GObject::PlainName);
}

int32_t
GPlanetTransfer::getDisplayOffset(GCargoType /*type*/)
{
    return 0;
}
